import os

from flask import Flask
from flask import request, render_template

templates = {}


def run_server(dir="./"):
    return


def read_files(dir):
    thisdir = os.getcwd()

    # r=root, d=directories, f = files
    for r, d, f in os.walk(thisdir):
        for file in f:
            if ".docx" in file:
                print(os.path.join(r, file))
                templates[:file.index(".")] = os.path.join(r, file)

    print(templates)


def start_flask_server():
    app = Flask(__name__)

    @app.route('{template}')
    def serve_template():
        template = request.match_info['user']
        if template in templates:
            return render_template(templates[template])
        return 404



import setuptools
from distutils.core import setup

setup(
    name='Jinja2 Dev Server',
    version="0.0.2b1",
    author="Eamonn Nugent",
    author_email="eamonn.nugent@demilletech.net",
    packages=['jinja2-dev-server', ],
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
)
